| adlp_partition | R Documentation |
General framework for any user-defined function for partitions of claims triangle data.
adlp_partition(df, ...)
adlp_partition_none(df)
adlp_partition_ap(df, tri.size, size = 1, weights = rep(1, size))
df |
data.frame format of claims and related information for each cell.
Dataframe will have columns |
... |
Other parameters used to calculate ADLP partitions |
tri.size |
Triangle size in claims |
size |
Number of partitions |
weights |
a vector of weights for the size of each partition. |
adlp_partition_none is the default functionality with no partitions. This is
equivalent to the standard linear pooling.
adlp_partition_ap will partition the claims triangle by accident period,
Where the choice of accident period to partition will be determined to most
closely resemble the desired weights.
The choice of accident period relies on a greedy algorithm that aims to find the accident period that provides the amount of cells that is larger or equal to the desired split.
List containing the df as a result of the partitions.
adlp_partition_none, adlp_partition_ap
data("test_claims_dataset")
adlp_partition_none(test_claims_dataset)
data("test_claims_dataset")
adlp_partition_ap(test_claims_dataset, tri.size = 40, size = 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.